@@ -1,3 +1,7 @@
+
+
+
+
 #' @title Construction of the honeycomb selection design.
 #' 
 #' @description This function creates a data frame of a  honeycomb selection design.
@@ -7,7 +11,7 @@
 #' @param rows The number of rows. 
 #' @param plpr The number of plants per row.
 #' @param distance The plant-to-plant distance in meters.
-#'  
+#' @param control Convert the design to controlled. 
 #' @param poly If TRUE the polygon pattern is displayed.
 
 #' @return A dataframe.
@@ -31,7 +35,7 @@
 
 
 
-HSD<-function(E,K,rows,plpr,distance,poly=TRUE ){
+HSD<-function(E,K,rows,plpr,distance,poly=TRUE , control=FALSE){
     R<-E
     #Added these two lines as suggested so the old adjustments will be restored 
     oldpar <- graphics::par(no.readonly = TRUE) 
@@ -142,14 +146,35 @@ HSD<-function(E,K,rows,plpr,distance,poly=TRUE ){
     #Main_Data_Frame<<-main_data
     #cat("Analysis table is saved in \"Main_Data_Frame\"\n\n\n")
     #print(main_data)
+
+
+    #Here convert the replicated to design with controls if it stated 
+    if(control==TRUE){
+        counter<-1
+        for(i in 1:nrow(main_data)){
+            if(main_data$Entry[i]==E){
+                main_data$Entry[i]<-"Control1"
+            } else {
+                main_data$Entry[i]<-counter
+                counter<-counter+1
+            }
+        }
+
+    }
+
+
     plot_convert(main_data,poly,rep_unrep=rep_unrep)
     return(main_data)
 }
 
 
+
+
+
+
 #' @title Construction of the honeycomb selection design without control.
 #' 
-#' @description This function creates a data frame of an  honeycomb selection design (one entry, without control).
+#' @description This function creates a data frame of a  honeycomb selection design (one entry, without control).
 #'
 #' @param  rows The number of rows. 
 #' @param  plpr The number of plants per row.
@@ -218,7 +243,7 @@ HSD0<-function(rows,plpr,distance,poly=TRUE){
 
 #' @title Construction of the honeycomb selection design with one control.
 #' 
-#' @description This function creates a data frame of an  honeycomb selection design  (one entry, one control).
+#' @description This function creates a data frame of a  honeycomb selection design  (one entry, one control).
 #' @param  K The K parameter.  
 #' @param  rows The number of rows. 
 #' @param  plpr The number of plants per row.
@@ -469,7 +494,7 @@ HSD03<-function(K,rows,plpr,distance,poly=TRUE){
 #' @param Response_Vector A vector containing the response variable data.
 #' @param ring The number of plants per moving ring.
 #' @param blocks The moving circular block.
-#' @param row_element The position of the plant (number of row) in the centerof a moving ring/circular block.
+#' @param row_element The position of the plant (number of row) in the center of a moving ring/circular block.
 #' @param plant_element  The position of the plant (number of plant) in the center of a moving ring/circular block.  
 #' @param CRS The number of selected plants used for the CRS index.
 #' @param Main_Data_Frame A data frame generated by one of the functions HSD(), HSD0(), HSD01() and HSD03().
@@ -491,11 +516,18 @@ HSD03<-function(K,rows,plpr,distance,poly=TRUE){
 #' 
 #' analysis(main_data,"Data",6)
 #' @export
-analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE,row_element=NULL,plant_element=NULL,CRS=5){
+analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE,row_element=NULL,plant_element=NULL,CRS=NULL   ){
+    #add this so that is known if CRS is null for later use.
+    if(is.null(CRS)){
+        null_crs<-TRUE
+        CRS<-5
+    } else {
+        null_crs<-FALSE
+    }
     #Added these two lines as suggested so the old adjustments will be restored 
     oldpar <- graphics::par(no.readonly = TRUE) 
     on.exit(graphics::par(oldpar))  
-
+    analysis_column_name<-Response_Vector
 
     #Check for NA (because there is an issue when inserted from excell)
     for(i in 1:nrow(Main_Data_Frame)){
@@ -556,6 +588,19 @@ analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE
                 Main_Data_Frame[[2]]$CRS[i]<-NA
             }
         }
+        colnames(Main_Data_Frame[[1]])<-c("Entry","Row","Plant","XPos","YPos","Data","SizeB","MeanB","PYE","E_Mean","N","E_sd","E_HI","PPE","CRS")
+        colnames(Main_Data_Frame[[2]])<-c("Entry","N","E_Mean","CV","E_sd","E_HI","GYI","GPE","mPYE","mPPE","CRS")
+        
+
+        #Add these quantities for the whole experiment also (mentioned afterwards)
+        trial_data_frame<-data.frame("GrandMean"=mean(Main_Data_Frame[[1]]$Data,na.rm=TRUE),
+                                     "sd"=sd(Main_Data_Frame[[1]]$Data,na.rm=TRUE),
+                                     "CV"=100*sd(Main_Data_Frame[[1]]$Data,na.rm=TRUE)/mean(Main_Data_Frame[[1]]$Data,na.rm=TRUE))
+        
+        #Add the trial_data_frame 
+        #also round the results at 4 digits
+        #Here main data frame is not actually a data frame
+        Main_Data_Frame<-list(round(Main_Data_Frame[[1]],4),round(Main_Data_Frame[[2]],4),round(trial_data_frame,4))
         return(Main_Data_Frame)
     }
  
@@ -780,7 +825,7 @@ analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE
             }        
           
 
-            #fill the table with the current values
+            #Fill the table with the current values
             for(k in 1:nrow(Main_Data_Frame)){
                 
                 if(Main_Data_Frame$Entry[k]==entry_elements[j]){
@@ -798,7 +843,7 @@ analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE
 
     }
 
-    if(rep_unrep=="rep"){
+    if(rep_unrep=="rep" && !is.null(CRS) ){
     #New index Coefficient of  Response to Selection (CRS).
     #Create a data frame with the max values 
     Entry_for_CRS<-factor(Main_Data_Frame$Entry)
@@ -895,7 +940,7 @@ analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE
         }
     }
      
-    #Replace the CRS of the control entry with NA. This only if the experiment is unreplicated
+    #Replace the CRS of the control entry with NA. This only if the experiment is replicated
     if(rep_unrep=="rep"){
         for (i in 1:nrow(summary_table_global)){
             if(summary_table_global$Entry[i]==summary_table_global$Entry[nrow(summary_table_global)]){
@@ -903,10 +948,125 @@ analysis<-function(Main_Data_Frame=NULL,Response_Vector=NULL,ring=6,blocks=FALSE
             }
         }
     }
-    return_value<-list(Main_Data_Frame[,!names(Main_Data_Frame) %in% c("mPPE","mPYI","GPE","GYI","CRS")],summary_table_global)
+
+
+
+    #Here some name changes were made for the columns
+    if(rep_unrep=="rep"){
+        colnames(Main_Data_Frame)<-c("Entry" ,"Row","Plant","XPos","YPos", "Data","NumR","MeanR","PYE","E_Mean","N","E_sd","E_HI","GYI","PPE","GPE","mPYE" ,"mPPE","CRS")
+        colnames(summary_table_global)<-c("Entry","N","E_Mean","CV","E_sd","E_HI","GYI","GPE","mPYE","mPPE","CRS")
+    } else {#If unreplicated there is no need for renaming the second data frame
+         
+        colnames(Main_Data_Frame)<-c( "Entry","Row","Plant","XPos","YPos","Data","NumR","MeanR","PYE")
+    }
+ 
+    #print(Main_Data_Frame)
+    #print(summary_table_global)
+    return_value<-list(Main_Data_Frame[,!names(Main_Data_Frame) %in% c("mPPE","mPYE","GPE","GYI","CRS")],summary_table_global)
     
 
-    return(return_value)
+
+    #Add an extra table as proposed  (regarding the whole plot). Similar change was made for the block analysis
+    trial_data_frame<-data.frame("GrandMean"=mean(return_value[[1]]$Data,na.rm=TRUE),
+                                 "sd"=sd(return_value[[1]]$Data,na.rm=TRUE),
+                                 "CV"=100*sd(return_value[[1]]$Data,na.rm=TRUE)/mean(return_value[[1]]$Data,na.rm=TRUE),
+                                 "Ring"=ring,
+                                 "CRS"=CRS
+                                 )
+
+
+
+    #If the design is unreplicated then the second table should be different than the replicated design
+    #For every control calculate mean sd cv an number of plants 
+    if(rep_unrep=="unrep"){
+        #initialize the values for the controls
+        control_name    <-c()
+        number_control  <-c()
+        mean_control    <-c()
+        sd_control      <-c()
+        cv_control      <-c()
+
+        if(("Control1" %in% return_value[[1]]$Entry)){
+             #Have stored the name of the column for larer use in the begining of the function
+
+            control_name    <- append(control_name,"Control1")
+
+            number_control <- append(number_control,length(   return_value[[1]][return_value[[1]]=="Control1"]           )
+            )         
+            mean_control   <- append(mean_control,mean(     return_value[[1]][return_value[[1]]=="Control1",analysis_column_name   ],na.rm=TRUE)
+            )                    
+            sd_control     <-append(sd_control,sd(       return_value[[1]][return_value[[1]]=="Control1",analysis_column_name   ],na.rm=TRUE)
+            )
+            cv_control     <-append(cv_control,100*sd(       return_value[[1]][return_value[[1]]=="Control1",analysis_column_name   ],na.rm=TRUE)/mean(return_value[[1]][return_value[[1]]=="Control1",analysis_column_name],na.rm=TRUE)
+           )
+        } 
+        if(("Control2" %in% return_value[[1]]$Entry)){
+             #Have stored the name of the column for larer use in the begining of the function
+
+            control_name    <- append(control_name,"Control2")
+
+            number_control <- append(number_control,length(   return_value[[1]][return_value[[1]]=="Control2"]           )
+            )         
+            mean_control   <- append(mean_control,mean(     return_value[[1]][return_value[[1]]=="Control2",analysis_column_name   ],na.rm=TRUE)
+            )                    
+            sd_control     <-append(sd_control,sd(       return_value[[1]][return_value[[1]]=="Control2",analysis_column_name   ],na.rm=TRUE)
+            )
+            cv_control     <-append(cv_control,100*sd(       return_value[[1]][return_value[[1]]=="Control2",analysis_column_name   ],na.rm=TRUE)/mean(return_value[[1]][return_value[[1]]=="Control2",analysis_column_name],na.rm=TRUE)
+           )
+        } 
+        if(("Control3" %in% return_value[[1]]$Entry)){
+             #Have stored the name of the column for larer use in the begining of the function
+
+            control_name    <- append(control_name,"Control3")
+
+            number_control <- append(number_control,length(   return_value[[1]][return_value[[1]]=="Control3"]           )
+            )         
+            mean_control   <- append(mean_control,mean(     return_value[[1]][return_value[[1]]=="Control3",analysis_column_name   ],na.rm=TRUE)
+            )                    
+            sd_control     <-append(sd_control,sd(       return_value[[1]][return_value[[1]]=="Control3",analysis_column_name   ],na.rm=TRUE)
+            )
+            cv_control     <-append(cv_control,100*sd(       return_value[[1]][return_value[[1]]=="Control3",analysis_column_name   ],na.rm=TRUE)/mean(return_value[[1]][return_value[[1]]=="Control3",analysis_column_name],na.rm=TRUE)
+           )
+        } 
+          
+           
+         #This reffered to the population so no need to check something
+         #keep the name control though
+         #Do this with a loop because doesnt work properly
+
+        #create vector to store the values of the plants wich are not controls
+        population<-c()
+        for(i in 1:nrow(return_value[[1]])) {
+            if(   !(return_value[[1]][i,"Entry"] %in% c("Control1","Control2","Control3"))){
+                population<-append(population,return_value[[1]][i,analysis_column_name])
+            }
+        }
+        control_name    <- append(control_name,"Population")
+        number_control <- append(number_control,length( population))         
+        mean_control   <- append(mean_control,mean(    population,na.rm=TRUE) )                   
+        sd_control     <-append(sd_control,sd(      population,na.rm=TRUE))
+        cv_control     <-append(cv_control,100*sd(   population,na.rm=TRUE)/mean(population,na.rm=TRUE))
+        
+        return_value[[2]]<-data.frame("Entry"=control_name,"N"=number_control,"Mean"=mean_control,"sd"=sd_control,"CV"=cv_control)
+
+    }    
+
+
+    #Round the result  and add the trial_data_frame use the [[1]][-1] to indicate  all columns except the 1st
+    #trial_data_frame contains only numeric sono need to round seperately
+    return_value[[1]][-1]<-round(return_value[[1]][-1],4)
+    return_value[[2]][-1]<-round(return_value[[2]][-1],4)
+    return_value<-list( return_value[[1]],  return_value[[2]]    , "Trial"= round(trial_data_frame ,4)       )
+    
+    if(null_crs | rep_unrep=="unrep"){#If the crs was null then  do that
+        return_value[[3]]['CRS']<-"-"
+        return(list(return_value[[1]],return_value[[2]][-11],return_value[[3]]))
+
+        
+    } else {
+        return(return_value)
+    }
+    
 }
 
 
